@@ -13,9 +13,9 @@ class ftpUtil:
     __password_media = "ywq20120721"
     __username_stud ="student"
     __password_stud ="student"
-    __remotedir_media = "/media/"
-    __remotedir_stud = "/send/"
-    __url_head="http://i.hddly.cn/stud/"
+    __remotedir_media = "media/"
+    __remotedir_stud = "send/"
+    __url_head="https://home.hddly.cn:8443/stud/"
     __mutil= mysqlUtil()
 
     def chk_file_exist_surl(self,surl,fdesc):
@@ -44,7 +44,7 @@ class ftpUtil:
             transport.connect(username=self.__username_stud, password=self.__password_stud)
             sftp = paramiko.SFTPClient.from_transport(transport)
             pid="p" + prj_id.zfill(6)
-            remotepath = self.__remotedir_stud + pid
+            remotepath = "%s%s"%(self.__remotedir_stud , pid)
             try:
                 sftp.chdir(remotepath)
             except:
@@ -52,7 +52,7 @@ class ftpUtil:
                 sftp.chdir(remotepath)
             stud = stud_id.zfill(11)
             no = no_file.zfill(8)
-            remote_file = pid + "_" + stud + "_" + no + ftype
+            remote_file = "%s%s%s%s"%(pid,stud,no,ftype)
             sftp.put(local_path, remote_file)
             print('success upload......')
             sftp.close()
@@ -66,8 +66,12 @@ class ftpUtil:
             # item['filename'] = local_path
             # item['url'] = self.__url_head+remote_file
             # item['stud'] = stud
+            remotefullpath = "%s%s%s/%s" % (self.__url_head,
+                                           self.__remotedir_stud,
+                                           pid,
+                                           remote_file)
             self.__mutil.sftp_file_ins(local_path,
-                                       self.__url_head +pid +'/'+ remote_file,
+                                       remotefullpath,
                                        stud,
                                        fdesc,
                                        fsize,
